@@ -37,7 +37,9 @@
 #'
 #'
 validate_crs <- function(crs, arg = rlang::caller_arg(crs), call = rlang::caller_env()) {
-
+  if (rlang::is_null(crs)) {
+    return(list(spatialReference = c()))
+  }
   if (!((inherits(crs, "character") || inherits(crs, "crs") || inherits(crs, "numeric")))) {
     cli::cli_abort(c(
       "Invalid CRS supplied: {.arg {arg}}",
@@ -64,5 +66,3 @@ validate_crs <- function(crs, arg = rlang::caller_arg(crs), call = rlang::caller
   sr_components <- compact(list(wkid = wkid, wkt = wkt))
   list(spatialReference = sr_components)
 }
-
-
